pub fn print_unicode_b<T: AsRef<Vec<u32>>>(unicode_cp: T)Expand description
Pretty print the unicode code points in hexadecimal and decimal of a vector of unicode code points.
Parameters
unicode_cp:Vec<u32>- A vector of unicode code points.
Note
The bytes printed in hexadecimal are code points in unicode.
Example
use ende::prelude::*;
let v: Vec<u32> = vec![0x10001];
print_unicode_b(&v);Output
--------------- UNICODE code points ---------------
Hex: [10001]
Bin: ["10000000000000001"]
Dec: [65537]
---------------------------------------------------